if RUBY_VERSION >= '1.9.1'
  Encoding.default_external = "UTF-8"
end

#tests requiring an access to the Internet
EXC_TESTS = [
  "test/functional/bio/appl/test_blast.rb",
  "test/functional/bio/io/test_togows.rb",
  "test/functional/bio/io/test_pubmed.rb",
  "test/functional/bio/appl/test_pts1.rb",
  "test/functional/bio/appl/blast/test_remote.rb",
  "test/functional/bio/io/test_ddbjrest.rb",
  "test/functional/bio/io/test_ensembl.rb",
  "test/functional/bio/test_command.rb"
]

$: << 'lib' << 'test' << '.'
(Dir['test/{unit,functional}/**/test_*.rb'] - EXC_TESTS).each { |f| require f }
